#!/bin/sh
# Generated by `baton admin releases stage` for mac-drive 0.1.0.
set -e
dest="${BATON_INSTALL_BIN:-$HOME/.local/bin}"
mkdir -p "$dest"
for f in mac-drive; do
	install -m 0755 "./$f" "$dest/$f"
done
echo "mac-drive 0.1.0: installed mac-drive -> $dest"
